import javax.swing.*;
import javax.swing.filechooser.*;
import java.io.*;
import java.beans.*; //Property change stuff
import java.awt.*;
import java.awt.event.*;

class CreateJobDialog extends JDialog {
    private boolean canceled = true;
	private String jobDefinition = null;
	private JOptionPane optionPane;

	public boolean isCanceled() {
        return canceled;
    }
	
	public String getJobDefinition() {
        return jobDefinition;
    }
	
	
	public CreateJobDialog(Frame aFrame) {
        super(aFrame, true);
        setTitle("Enter Complete or Partial Job Definition");
		
        final JLabel defLabel = new JLabel("Job Definition: ");
		final JTextArea defField = new JTextArea( 
							"; Comments: this simple job will start Notepad on\n" +
                            ";           the first business day of every month\n" +
                            ";           In case if an error occurs the job will\n" +
                            ";           send an email message to the specified\n" +
                            ";           recipient.\n" +
                            "[Variables]\n" +
                            "NAME = Dynamic Java job\n" +
                            "JOB_TYPE = P\n" +
                            "COMMAND = notepad.exe\n" +
                            "SCHEDULE_TYPE = M\n" +
                            "MONTHLY_TYPE = T\n" +
                            "DAY_NUMBER = First\n" +
                            "DAY_NAME = Weekday\n" +
                            "SLIDE_HOLIDAY = Y\n" +
                            "START_TIME = 09:00\n" +
                            "SKIP = N\n" +
                            "ASYNC = Y\n" +
                            "MSG_ERROR = Y\n" +
                            "MSG_EMAIL = Y\n" +
                            "MSG_ACCOUNT = your email profile here\n" +
                            "MSG_PASSWORD = your email password here\n" +
                            "MSG_RECIPIENT = email recipient here\n" +
                            "DESCRIPTION=Every month on the first business day this job kicks off the Windows Notepad.");
		
		final JScrollPane editor = new JScrollPane(defField);
        editor.setMinimumSize(new Dimension(300, 300));
		Object[] array = {defLabel, editor};

        final String btnCreate = "Create";
        final String btnCancel = "Cancel";
		final String btnTemplate = "Template...";
        Object[] options = {btnCreate, btnCancel, btnTemplate};

        optionPane = new JOptionPane(array, 
                                    JOptionPane.PLAIN_MESSAGE,
                                    JOptionPane.OK_CANCEL_OPTION,
                                    null,
                                    options,
                                    options[0]);
		optionPane.setPreferredSize(new Dimension(350, 400));
		setContentPane(optionPane);
		setDefaultCloseOperation(DO_NOTHING_ON_CLOSE);
        addWindowListener(new WindowAdapter() {
                public void windowClosing(WindowEvent we) {
                /*
                 * Instead of directly closing the window,
                 * we're going to change the JOptionPane's
                 * value property.
                 */
                    optionPane.setValue(new Integer(
                                        JOptionPane.CLOSED_OPTION));
            }
        });

        optionPane.addPropertyChangeListener(new PropertyChangeListener() {
            public void propertyChange(PropertyChangeEvent e) {
                String prop = e.getPropertyName();

                if (isVisible() 
                 && (e.getSource() == optionPane)
                 && (prop.equals(JOptionPane.VALUE_PROPERTY) ||
                     prop.equals(JOptionPane.INPUT_VALUE_PROPERTY))) {
                     Object value = optionPane.getValue();

                    if (value == JOptionPane.UNINITIALIZED_VALUE) {
                        //ignore reset
                        return;
                    }

                    // Reset the JOptionPane's value.
                    // If you don't do this, then if the user
                    // presses the same button next time, no
                    // property change event will be fired.
                    optionPane.setValue(JOptionPane.UNINITIALIZED_VALUE);

                    if (value.equals(btnCreate)) {
						canceled = false;
                        jobDefinition = defField.getText();
                    }
					else if	(value.equals(btnTemplate)) {
						// display File Open dialog
						JFileChooser chooser = new JFileChooser(); 
						ExampleFileFilter filter = new ExampleFileFilter(); 
						filter.addExtension("ini"); 
						filter.setDescription("Job Template File"); 
						chooser.setFileFilter(filter); 
						chooser.setCurrentDirectory(new File("C:\\Program Files\\24x7 Scheduler 2.0\\Template"));
						int returnVal = chooser.showOpenDialog(optionPane); 
						if(returnVal == chooser.APPROVE_OPTION) { 
							File templateFile = chooser.getSelectedFile();
							defLabel.setText("Job Definition - Template: " + templateFile.getName());
							try 
							{
								FileReader in = new FileReader(templateFile);
								char c[] = new char[(int)templateFile.length()];
								in.read(c);
								in.close();
								defField.setText(new String(c));
				            } 
							catch(java.io.IOException fe) {
								System.err.println("Cannot read template file.");
				            }

							return;
						}
                    }
					
					setVisible(false);
                }
            }
        });
    }
}
